==> bluefish_0.13.orig.tar.gz: bluefish-0.13/inline_images/general_icons.c <==
/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (close_small)
#endif
#ifdef __GNUC__
const guint8 close_small[] __attribute__ ((__aligned__ (4))) = 
#else
const guint8 close_small[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (196) */
  "\0\0\0\334"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (28) */
  "\0\0\0\34"
  /* width (7) */
  "\0\0\0\7"
  /* height (7) */
  "\0\0\0\7"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0"
  "\0\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\377"
  "\0\0\0\0\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\377\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\377\0\0\0\377"};


/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (edit_tag)
#endif
#ifdef __GNUC__
const guint8 edit_tag[] __attribute__ ((__aligned__ (4))) = 
#else
const guint8 edit_tag[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (1156) */
  "\0\0\4\234"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (68) */
  "\0\0\0D"
  /* width (17) */
  "\0\0\0\21"
  /* height (17) */
  "\0\0\0\21"
  /* pixel_data: */
  "\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317"
  "\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317"
  "\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317"
  "\0\337\330\317\0\337\330\317\0\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\337\330\317\0\337"
  "\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\337"
  "\330\317\0\337\330\317\0\0\0\0\377\377\377\237\377\377\377\237\377\377"
  "\377\237\377\377\377\237\377\377\377\237\377\377\377\237\377\377\377"
  "\237\377\0\0\0\377\0\0\0\377\337\330\317\0\337\330\317\0\337\330\317"
  "\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\0\0\0\377"
  "\377\377\237\377\377\377\237\377\377\377\237\377\377\377\237\377\377"
  "\377\237\377\377\377\237\377\377\377\237\377\0\0\0\377\377\377\237\377"
  "\0\0\0\377\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\337"
  "\330\317\0\337\330\317\0\0\0\0\377\377\377\237\377\377\377\237\377\377"
  "\377\237\377\377\377\237\377\377\377\237\377\377\377\237\377\377\377"
  "\237\377\0\0\0\377\377\377\237\377\377\317\237\377\0\0\0\377\337\330"
  "\317\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\0\0\0"
  "\377\377\377\237\377\377\377\237\377\377\377\237\377\377\377\237\377"
  "\377\377\237\377\377\377\237\377\377\377\237\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\337\330\317\0\337\330\317\0\337\330\317"
  "\0\337\330\317\0\0\0\0\377\377\377\237\377\377\377\237\377\0\0\0\377"
  "\0\0\0\377\377\317\237\377\377\377\237\377\377\377\237\377\377\377\237"
  "\377\377\317\237\377\237`\0\377\377\317\237\377\0\0\0\377\337\330\317"
  "\0\337\330\317\0\337\330\317\0\337\330\317\0\0\0\0\377\377\377\237\377"
  "\0\0\0\377\377\377\237\377\377\377\237\377\0\0\0\377\377\317\237\377"
  "\377\377\237\377\377\377\237\377\237`\0\377\377\237\237\377\237`\0\377"
  "\0\0\0\377\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\0"
  "\0\0\377\377\377\237\377\0\0\0\377\377\377\237\377\377\317\237\377\0"
  "\0\0\377\377\317\237\377\0\0\0\377\0\0\0\377\237`\0\377\377\317\317\377"
  "\237`\0\377\0\0\0\377\337\330\317\0\337\330\317\0\337\330\317\0\337\330"
  "\317\0\0\0\0\377\377\377\237\377\377\377\237\377\0\0\0\377\0\0\0\377"
  "\377\317\237\377\377\377\237\377\377\377\237\377\377\317\237\377\237"
  "`\0\377\377\317\317\377\237`\0\377\237`\0\377\237`\0\377\337\330\317"
  "\0\337\330\317\0\337\330\317\0\0\0\0\377\377\377\237\377\377\377\237"
  "\377\377\377\237\377\377\377\237\377\377\377\237\377\377\377\237\377"
  "\377\377\237\377\377\377\237\377\237`\0\377\377\317\317\377\237`\0\377"
  "\377\317\317\377\237`\0\377\237`\0\377\237`\0\377\337\330\317\0\0\0\0"
  "\377\377\377\237\377\377\377\237\377\0\0\0\377\0\0\0\377\377\317\237"
  "\377\377\377\237\377\377\377\237\377\237`\0\377\237`\0\377\377\317\317"
  "\377\237`\0\377\377\317\317\377\237`\0\377\377\317\317\377\237`\0\377"
  "\337\330\317\0\0\0\0\377\377\377\237\377\0\0\0\377\377\377\237\377\377"
  "\377\237\377\0\0\0\377\377\317\237\377\377\377\237\377\237`\0\377\377"
  "\317\317\377\377\317\317\377\237`\0\377\377\317\317\377\237`\0\377\377"
  "\317\317\377\237`\0\377\337\330\317\0\0\0\0\377\377\377\237\377\0\0\0"
  "\377\377\377\237\377\377\317\237\377\0\0\0\377\377\317\237\377\0\0\0"
  "\377\237`\0\377\377\317\317\377\377\317\317\377\377\317\317\377\377\317"
  "\317\377\377\317\317\377\377\317\317\377\237`\0\377\337\330\317\0\0\0"
  "\0\377\377\377\237\377\377\377\237\377\0\0\0\377\0\0\0\377\377\317\237"
  "\377\377\317\237\377\377\317\237\377\237`\0\377\377\317\317\377\377\317"
  "\317\377\377\317\317\377\377\317\317\377\377\317\317\377\377\237\237"
  "\377\237`\0\377\337\330\317\0\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\237`\0\377\377\317"
  "\317\377\377\317\317\377\377\317\317\377\377\237\237\377\377\237\237"
  "\377\237`\0\377\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317"
  "\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317"
  "\0\337\330\317\0\337\330\317\0\237`\0\377\237`\0\377\237`\0\377\237`"
  "\0\377\237`\0\377\337\330\317\0\337\330\317\0"};

==> bluefish_1.0.orig.tar.gz: bluefish-1.0/inline_images/general_icons.c <==
/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (pixmap_close_small)
#endif
#ifdef __GNUC__
const guint8 pixmap_close_small[] __attribute__ ((__aligned__ (4))) = 
#else
const guint8 pixmap_close_small[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (196) */
  "\0\0\0\334"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (28) */
  "\0\0\0\34"
  /* width (7) */
  "\0\0\0\7"
  /* height (7) */
  "\0\0\0\7"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0"
  "\0\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0\377"
  "\0\0\0\0\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\0\0\0\0\377\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\377\0\0\0\377"};


/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (pixmap_edit_tag)
#endif
#ifdef __GNUC__
const guint8 pixmap_edit_tag[] __attribute__ ((__aligned__ (4))) = 
#else
const guint8 pixmap_edit_tag[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (1156) */
  "\0\0\4\234"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (68) */
  "\0\0\0D"
  /* width (17) */
  "\0\0\0\21"
  /* height (17) */
  "\0\0\0\21"
  /* pixel_data: */
  "\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317"
  "\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317"
  "\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317"
  "\0\337\330\317\0\337\330\317\0\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\337\330\317\0\337"
  "\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\337"
  "\330\317\0\337\330\317\0\0\0\0\377\377\377\237\377\377\377\237\377\377"
  "\377\237\377\377\377\237\377\377\377\237\377\377\377\237\377\377\377"
  "\237\377\0\0\0\377\0\0\0\377\337\330\317\0\337\330\317\0\337\330\317"
  "\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\0\0\0\377"
  "\377\377\237\377\377\377\237\377\377\377\237\377\377\377\237\377\377"
  "\377\237\377\377\377\237\377\377\377\237\377\0\0\0\377\377\377\237\377"
  "\0\0\0\377\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\337"
  "\330\317\0\337\330\317\0\0\0\0\377\377\377\237\377\377\377\237\377\377"
  "\377\237\377\377\377\237\377\377\377\237\377\377\377\237\377\377\377"
  "\237\377\0\0\0\377\377\377\237\377\377\317\237\377\0\0\0\377\337\330"
  "\317\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\0\0\0"
  "\377\377\377\237\377\377\377\237\377\377\377\237\377\377\377\237\377"
  "\377\377\237\377\377\377\237\377\377\377\237\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\337\330\317\0\337\330\317\0\337\330\317"
  "\0\337\330\317\0\0\0\0\377\377\377\237\377\377\377\237\377\0\0\0\377"
  "\0\0\0\377\377\317\237\377\377\377\237\377\377\377\237\377\377\377\237"
  "\377\377\317\237\377\237`\0\377\377\317\237\377\0\0\0\377\337\330\317"
  "\0\337\330\317\0\337\330\317\0\337\330\317\0\0\0\0\377\377\377\237\377"
  "\0\0\0\377\377\377\237\377\377\377\237\377\0\0\0\377\377\317\237\377"
  "\377\377\237\377\377\377\237\377\237`\0\377\377\237\237\377\237`\0\377"
  "\0\0\0\377\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\0"
  "\0\0\377\377\377\237\377\0\0\0\377\377\377\237\377\377\317\237\377\0"
  "\0\0\377\377\317\237\377\0\0\0\377\0\0\0\377\237`\0\377\377\317\317\377"
  "\237`\0\377\0\0\0\377\337\330\317\0\337\330\317\0\337\330\317\0\337\330"
  "\317\0\0\0\0\377\377\377\237\377\377\377\237\377\0\0\0\377\0\0\0\377"
  "\377\317\237\377\377\377\237\377\377\377\237\377\377\317\237\377\237"
  "`\0\377\377\317\317\377\237`\0\377\237`\0\377\237`\0\377\337\330\317"
  "\0\337\330\317\0\337\330\317\0\0\0\0\377\377\377\237\377\377\377\237"
  "\377\377\377\237\377\377\377\237\377\377\377\237\377\377\377\237\377"
  "\377\377\237\377\377\377\237\377\237`\0\377\377\317\317\377\237`\0\377"
  "\377\317\317\377\237`\0\377\237`\0\377\237`\0\377\337\330\317\0\0\0\0"
  "\377\377\377\237\377\377\377\237\377\0\0\0\377\0\0\0\377\377\317\237"
  "\377\377\377\237\377\377\377\237\377\237`\0\377\237`\0\377\377\317\317"
  "\377\237`\0\377\377\317\317\377\237`\0\377\377\317\317\377\237`\0\377"
  "\337\330\317\0\0\0\0\377\377\377\237\377\0\0\0\377\377\377\237\377\377"
  "\377\237\377\0\0\0\377\377\317\237\377\377\377\237\377\237`\0\377\377"
  "\317\317\377\377\317\317\377\237`\0\377\377\317\317\377\237`\0\377\377"
  "\317\317\377\237`\0\377\337\330\317\0\0\0\0\377\377\377\237\377\0\0\0"
  "\377\377\377\237\377\377\317\237\377\0\0\0\377\377\317\237\377\0\0\0"
  "\377\237`\0\377\377\317\317\377\377\317\317\377\377\317\317\377\377\317"
  "\317\377\377\317\317\377\377\317\317\377\237`\0\377\337\330\317\0\0\0"
  "\0\377\377\377\237\377\377\377\237\377\0\0\0\377\0\0\0\377\377\317\237"
  "\377\377\317\237\377\377\317\237\377\237`\0\377\377\317\317\377\377\317"
  "\317\377\377\317\317\377\377\317\317\377\377\317\317\377\377\237\237"
  "\377\237`\0\377\337\330\317\0\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\237`\0\377\377\317"
  "\317\377\377\317\317\377\377\317\317\377\377\237\237\377\377\237\237"
  "\377\237`\0\377\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317"
  "\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317\0\337\330\317"
  "\0\337\330\317\0\337\330\317\0\237`\0\377\237`\0\377\237`\0\377\237`"
  "\0\377\237`\0\377\337\330\317\0\337\330\317\0"};
